Documentation
¶
Index ¶
- func Compile[srcT, outT any](input string, ops ...Option) (func(srcT) outT, error)
- func RegisterBinary(token string, registrator ...registrators.Binary) error
- func RegisterConst(token string, registrator ...registrators.Const) error
- func RegisterFunc(token string, registrator ...registrators.Func) error
- func RegisterUnary(token string, registrator ...registrators.Unary) error
- func RegisterVarSource(registrator ...registrators.VarSourse)
- func RegisterVarType(registrator ...registrators.VariableType)
- type Env
- type Option
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegisterBinary ¶
func RegisterBinary(token string, registrator ...registrators.Binary) error
func RegisterConst ¶
func RegisterConst(token string, registrator ...registrators.Const) error
func RegisterFunc ¶
func RegisterFunc(token string, registrator ...registrators.Func) error
func RegisterUnary ¶
func RegisterUnary(token string, registrator ...registrators.Unary) error
func RegisterVarSource ¶
func RegisterVarSource(registrator ...registrators.VarSourse)
func RegisterVarType ¶
func RegisterVarType(registrator ...registrators.VariableType)
Types ¶
Directories
¶
| Path | Synopsis |
|---|---|
|
internal
|
|
|
difflib
Package difflib is a partial port of Python difflib module.
|
Package difflib is a partial port of Python difflib module. |
|
spew
Package spew implements a deep pretty printer for Go data structures to aid in debugging.
|
Package spew implements a deep pretty printer for Go data structures to aid in debugging. |
|
testify/assert
Package assert provides a set of comprehensive testing tools for use with the normal Go testing system.
|
Package assert provides a set of comprehensive testing tools for use with the normal Go testing system. |
|
testify/assert/internal/unsafetests
This package exists just to isolate tests that reference the unsafe package.
|
This package exists just to isolate tests that reference the unsafe package. |
|
testify/require
Package require implements the same assertions as the `assert` package but stops test execution when a test fails.
|
Package require implements the same assertions as the `assert` package but stops test execution when a test fails. |
|
tests
|
|
Click to show internal directories.
Click to hide internal directories.